Learn R Programming

schtools (version 0.4.1)

is_nearly_whole: Checks whether a number is near to a whole number

Description

Checks whether a number is near to a whole number

Usage

is_nearly_whole(x)

Value

TRUE or FALSE

Arguments

x

a numeric

Author

Kelly Sovacool sovacool@umich.edu

Examples

Run this code
is_nearly_whole(.Machine$double.eps^0.5)
is_nearly_whole(.Machine$double.eps^0.6)
is_nearly_whole(1)

Run the code above in your browser using DataLab