Learn R Programming

schtools (version 0.4.1)

is_nondesc: Check whether all elements given are sorted in non-descending order

Description

Check whether all elements given are sorted in non-descending order

Usage

is_nondesc(...)

Value

TRUE if the elements are sorted in non-descending order, otherwise FALSE

Arguments

...

anything!

Author

Kelly Sovacool sovacool@umich.edu

Examples

Run this code

is_nondesc(1, 2, 3)
is_nondesc(c(1, 2), 3)
is_nondesc(6, 4, 1)
is_nondesc("a", "b", "c")
is_nondesc(c("z", "y"))

Run the code above in your browser using DataLab